/* Copyright 2012 Mozilla Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 NOTE: This file is created as a helper to assist with JSDoc html files.
       It is not for use in the executable code.
*/

/**
 * PDFJS scope object that contains all functions, objects and variables related
 * to the PDF.js.
 * @constructor
 */
function PDFJS() {
  // Mock class constructor. See src/display/api.js.
}

/**
 * Controls the logging level.
 * The constants from PDFJS.VERBOSITY_LEVELS should be used:
 * - errors
 * - warnings [default]
 * - infos
 * @var {number}
 */
PDFJS.verbosity = PDFJS.VERBOSITY_LEVELS.warnings;

/**
 * Represents the eventual result of an asynchronous operation.
 * @external Promise
 * @see {@link http://promisesaplus.com/ Promise/A+}
 */
